From d481fbda755da5e7ab18f63f0f3fa1a1841b4622 Mon Sep 17 00:00:00 2001
From: Erik Andresen <erik@vontaene.de>
Date: Mon, 22 May 2017 21:08:02 +0200
Subject: [PATCH] fix spelling error

---
 scripts/tinkerforge_imu2.py | 10 +++++-----
 1 file changed, 5 insertions(+), 5 deletions(-)

diff --git a/scripts/tinkerforge_imu2.py b/scripts/tinkerforge_imu2.py
index fa00c26..2cf42b2 100755
--- a/scripts/tinkerforge_imu2.py
+++ b/scripts/tinkerforge_imu2.py
@@ -52,18 +52,18 @@ class ImuBrickv2:
 		msg.angular_velocity.x = angular_velocity[0]/16.0
 		msg.angular_velocity.y = angular_velocity[1]/16.0
 		msg.angular_velocity.z = angular_velocity[2]/16.0
 		# Observed angular velocity variance: 0.006223 (10k samples), => round up to 0.01
 		msg.angular_velocity_covariance = [
-			0.01, 0   , 0,
-			0   , 0.01, 0,
-			0   , 0   , 0.01
+			0.02, 0   , 0,
+			0   , 0.02, 0,
+			0   , 0   , 0.02
 		]
 
 		msg.linear_acceleration.x = linear_acceleration[0]/100.0
 		msg.linear_acceleration.y = linear_acceleration[1]/100.0
 		msg.linear_acceleration.z = linear_acceleration[2]/100.0
 		# Observed linear acceleration variance: 0.001532 (10k samples)
-		# Calculation for variance raken from razor imu:
+		# Calculation for variance taken from razor imu:
 		# nonliniarity spec: 1% of full scale (+-2G) => 0.2m/s^2
 		# Choosing 0.2 as std dev, variance = 0.2^2 = 0.04
 		msg.linear_acceleration_covariance = [
@@ -52,18 +52,18 @@ class ImuBrickv2:
 		msg.angular_velocity.y = angular_velocity[1]/16.0
 		msg.angular_velocity.z = angular_velocity[2]/16.0
-		# Observed angular velocity variance: 0.006223 (10k samples), => round up to 0.01
+		# Observed angular velocity variance: 0.006223 (10k samples), => round up to 0.02
 		msg.angular_velocity_covariance = [
-- 
2.39.5